summaryrefslogtreecommitdiff
path: root/jstests/multiVersion/verify_versions_test.js
diff options
context:
space:
mode:
authorJason Chan <jason.chan@mongodb.com>2020-07-14 20:50:12 +0000
committerEvergreen Agent <no-reply@evergreen.mongodb.com>2020-07-23 12:26:49 +0000
commit1c28b3cf02d42f3d3135560dddc43a851ccd801b (patch)
tree4549ad2cd3e19a0cec2483bc10c989805d297a78 /jstests/multiVersion/verify_versions_test.js
parente1f9d520c85c65b1fcf1d3affb067e4935c04c71 (diff)
downloadmongo-1c28b3cf02d42f3d3135560dddc43a851ccd801b.tar.gz
SERVER-49064 Update references of "last-stable" to use "last-continuous" and "last-lts"
Diffstat (limited to 'jstests/multiVersion/verify_versions_test.js')
-rw-r--r--jstests/multiVersion/verify_versions_test.js12
1 files changed, 6 insertions, 6 deletions
diff --git a/jstests/multiVersion/verify_versions_test.js b/jstests/multiVersion/verify_versions_test.js
index 535bdd0c142..f1a574c9b63 100644
--- a/jstests/multiVersion/verify_versions_test.js
+++ b/jstests/multiVersion/verify_versions_test.js
@@ -2,7 +2,7 @@
* These tests check the version comparison logic in the multiversion test support code.
*
* In particular, it tests that the shell version (returned by version()) compares equal to
* "latest", not equal to "last-stable", and x.y compares equal to x.y.z, but that x.w does
* not.
*/
@@ -45,7 +45,7 @@ function assertBinVersionComparesEqual(v1, v2) {
assertBinVersionsEqual("4.5", version());
assertBinVersionComparesEqual("4.5", version());
// "latest" is the same version as the shell, "last-stable" is not.
assertBinVersionsEqual("latest", version());
assertBinVersionsEqual("", "latest");
assertBinVersionsEqual("", version());
@@ -54,11 +54,11 @@ assertBinVersionComparesEqual("latest", version());
assertBinVersionComparesEqual("", "latest");
assertBinVersionComparesEqual("", version());
-assertBinVersionsNotEqual("latest", "last-stable");
-assertBinVersionsNotEqual("last-stable", version());
+assertBinVersionsNotEqual("latest", "last-lts");
+assertBinVersionsNotEqual("last-lts", version());
-assertBinVersionComparesHigher("latest", "last-stable");
-assertBinVersionComparesLower("last-stable", version());
+assertBinVersionComparesHigher("latest", "last-lts");
+assertBinVersionComparesLower("last-lts", version());
// 3.2 means 3.2.z for any value of z. It does not mean 3.0 or 3.0.w.
assertBinVersionsEqual("3.2", "3.2.4");
@@ -2,7 +2,7 @@
*
* In particular, it tests that the shell version (returned by version()) compares equal to
- * "latest", not equal to "last-stable", and x.y compares equal to x.y.z, but that x.w does
+ * "latest", not equal to "last-lts", and x.y compares equal to x.y.z, but that x.w does
* not.
*/
@@ -45,7 +45,7 @@ function assertBinVersionComparesEqual(v1, v2) {
assertBinVersionsEqual("4.5", version());
assertBinVersionComparesEqual("4.5", version());
-// "latest" is the same version as the shell, "last-stable" is not.
+// "latest" is the same version as the shell, "last-lts" is not.
assertBinVersionsEqual("latest", version());
assertBinVersionsEqual("", "latest");